colour.models.dataset.apple_rgb Module — Colour 0.3.0 documentation

# colour.models.dataset.apple_rgb Module

## Apple RGB Colourspace

Defines the Apple RGB colourspace:

- `APPLE_RGB_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.brucelindbloom.com/WorkingSpaceInfo.html (Last accessed 11 April 2014)

`colour.models.dataset.apple_rgb.` `APPLE_RGB_PRIMARIES` = array([[ 0.625, 0.34 ], [ 0.28 , 0.595], [ 0.155, 0.07 ]])

  Apple RGB colourspace primaries.

  APPLE_RGB_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.apple_rgb.` `APPLE_RGB_WHITEPOINT` = (0.31271, 0.32902)

  Apple RGB colourspace whitepoint.

  APPLE_RGB_WHITEPOINT : tuple

`colour.models.dataset.apple_rgb.` `APPLE_RGB_TO_XYZ_MATRIX` = array([[ 0.44965881, 0.31626366, 0.18450607], [ 0.24461439, 0.67206028, 0.08332532], [ 0.02518089, 0.14118914, 0.92253034]])

  Apple RGB colourspace to CIE XYZ colourspace matrix.

  APPLE_RGB_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.apple_rgb.` `XYZ_TO_APPLE_RGB_MATRIX` = array([[ 2.95199692, -1.28961236, -0.47391827], [-1.08505769, 1.99076185, 0.03720079], [ 0.08548709, -0.26947661, 1.09121759]])

  CIE XYZ colourspace to Apple RGB colourspace matrix.

  XYZ_TO_APPLE_RGB_MATRIX : array_like, (3, 3)

`colour.models.dataset.apple_rgb.` `APPLE_RGB_TRANSFER_FUNCTION`(x)

  Transfer function from linear to Apple RGB colourspace.

  APPLE_RGB_TRANSFER_FUNCTION : object

`colour.models.dataset.apple_rgb.` `APPLE_RGB_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from Apple RGB colourspace to linear.

  APPLE_RGB_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.apple_rgb.` `APPLE_RGB_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e12e90>

  Apple RGB colourspace.

  APPLE_RGB_COLOURSPACE : RGB_Colourspace